@@ -7,11 +7,11 @@ use experimental 'smartmatch';
 use Log::Any '$log';
 
 use List::Util qw(shuffle);
-use Locale::TextDomain 'Perinci-Sub-Gen-AccessTable';
+use Locale::TextDomain::UTF8 'Perinci-Sub-Gen-AccessTable';
 use Perinci::Object::Metadata;
 use Perinci::Sub::Gen;
 use Perinci::Sub::Util qw(err);
-use POSIX qw(locale_h);
+use SHARYANTO::Locale::Util qw(:locale_h);
 use Scalar::Util qw(reftype);
 #use SHARYANTO::String::Util qw(trim_blank_lines);
 
@@ -19,7 +19,7 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(gen_read_table_func);
 
-our $VERSION = '0.28'; # VERSION
+our $VERSION = '0.31'; # VERSION
 
 our %SPEC;
 
@@ -80,7 +80,7 @@ sub _add_arg {
         next unless defined $args{$prop};
         #$args{$prop} = trim_blank_lines($args{$prop});
         for my $lang (@$langs) {
-            setlocale(LC_ALL, $lang);
+            setlocale(LC_ALL, $lang) or warn "Can't setlocale $lang";
             my $isdeflang = $lang eq 'en_US';
             my $k = $prop . ($isdeflang ? '' : ".alt.lang.$lang");
             $arg_spec->{$k} = __x($args{$prop}, %xargs);
@@ -89,7 +89,7 @@ sub _add_arg {
 
     for my $lang (@$langs) {
         for my $prop (qw/summary/) {
-            setlocale(LC_ALL, $lang);
+            setlocale(LC_ALL, $lang) or warn "Can't setlocale $lang";
             my $isdeflang = $lang eq 'en_US';
             my $k = $prop . ($isdeflang ? '' : ".alt.lang.$lang");
             $tag->{$k} = __x($args{cat_text}, %xargs);
@@ -107,8 +107,8 @@ sub _add_table_desc_to_func_description {
     my $orig_locale = setlocale(LC_ALL);
 
     for my $lang (@$langs) {
-        setlocale(LC_ALL, $lang);
-        my $td = __ "Data is in table form. Table fields are as follow:";
+        setlocale(LC_ALL, $lang) or warn "Can't setlocale $lang";
+        my $td = __("Data is in table form. Table fields are as follow:");
         $td .= "\n\n";
         my $ff = $table_spec->{fields};
         for my $fn (sort {($ff->{$a}{index}//0) <=> ($ff->{$b}{index}//0)}
@@ -1308,7 +1308,7 @@ Perinci::Sub::Gen::AccessTable - Generate function (and its Rinci metadata) to a
 
 =head1 VERSION
 
-version 0.28
+version 0.31
 
 =head1 SYNOPSIS
 
@@ -1417,10 +1417,10 @@ This module uses L<Log::Any> for logging.
 =head1 FUNCTIONS
 
 
-None are exported by default, but they are exportable.
-
 =head2 gen_read_table_func(%args) -> [status, msg, result, meta]
 
+Generate function (and its metadata) to read table data.
+
 The generated function acts like a simple single table SQL SELECT query,
 featuring filtering, ordering, and paging, but using arguments as the 'query
 language'. The generated function is suitable for exposing a table data from an
@@ -1754,8 +1754,14 @@ This will not have effect under 'custom_search'.
 
 Return value:
 
-Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+Returns an enveloped result (an array).
 
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
 =head1 CAVEATS
 
 It is often not a good idea to expose your database schema directly as API.
@@ -1801,7 +1807,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
